## 东财概念板块行情

接口：dc_daily

描述：获取东财概念板块、行业指数板块、地域板块行情数据，历史数据开始于2020年

限量：单次最大2000条数据，可根据日期参数循环获取

权限：用户积累6000积分可调取，具体请参阅积分获取办法







注意：本接口只限个人学习和研究使用，如需商业用途，请自行联系东方财富解决数据采购问题。

输入参数

| 名称 | 类型 | 必选 | 描述 |
| --- | --- | --- | --- |
| ts_code | str | N | 板块代码（格式：xxxxx.DC) |
| trade_date | str | N | 交易日期(格式：YYYYMMDD下同） |
| start_date | str | N | 开始日期 |
| end_date | str | N | 结束日期 |
| idx_type | str | N | 板块类型： 概念板块、行业板块、地域板块 |

输出参数

| 名称 | 类型 | 默认显示 | 描述 |
| --- | --- | --- | --- |
| ts_code | str | Y | 板块代码 |
| trade_date | str | Y | 交易日 |
| close | float | Y | 收盘点位 |
| open | float | Y | 开盘点位 |
| high | float | Y | 最高点位 |
| low | float | Y | 最低点位 |
| change | float | Y | 涨跌点位 |
| pct_change | float | Y | 涨跌幅 |
| vol | float | Y | 成交量 |
| amount | float | Y | 成交额 |
| swing | float | Y | 振幅 |
| turnover_rate | float | Y | 换手率 |

接口示例

```python
#获取东方财富2025年5月13日概念板块行情
df = pro.dc_daily(trade_date='20250513')
```

数据示例

```python
ts_code trade_date       close        open        high         low pct_change
0    BK1063.DC   20250513    792.5200    793.5200    795.0400    786.9000     0.8700
```